searchData={"items":[{"type":"module","title":"Morpheus","doc":"Morpheus is an Elixir library for converting between camelCase and snake_case in Phoenix applications.\n\nThis module provides key conversion utilities for JSON payloads, allowing your Phoenix application\nto seamlessly work with camelCase (JavaScript) and snake_case (Elixir) conventions.","ref":"Morpheus.html"},{"type":"module","title":"Installation - Morpheus","doc":"Add to your mix.exs:\n\n    def deps do\n      [\n        {:morpheus, \"~> 0.1.0\"}\n      ]\n    end","ref":"Morpheus.html#module-installation"},{"type":"module","title":"Key Features - Morpheus","doc":"* Converts between camelCase and snake_case for strings and atoms\n  * Handles nested data structures (maps and lists)\n  * Preserves non-convertible values\n  * Properly handles acronyms (API, HTML, iOS)","ref":"Morpheus.html#module-key-features"},{"type":"module","title":"Quick Start - Morpheus","doc":"# Basic conversion\n    \"user_name\" |> Morpheus.snake_to_camel()     # => \"userName\"\n    \"userName\" |> Morpheus.camel_to_snake()      # => \"user_name\"\n\n    # Convert map keys\n    data = %{user_profile: %{first_name: \"John\"}}\n    Morpheus.convert_map_keys(data, &Morpheus.snake_to_camel/1)\n    # => %{userProfile: %{firstName: \"John\"}}","ref":"Morpheus.html#module-quick-start"},{"type":"module","title":"Usage with Phoenix - Morpheus","doc":"For automatic JSON conversion, see `Morpheus.Encoder`.","ref":"Morpheus.html#module-usage-with-phoenix"},{"type":"function","title":"Morpheus.camel_to_snake/1","doc":"Converts a camelCase string or atom to snake_case.","ref":"Morpheus.html#camel_to_snake/1"},{"type":"function","title":"String Conversion - Morpheus.camel_to_snake/1","doc":"# Basic conversion\n    iex> Morpheus.camel_to_snake(\"userName\")\n    \"user_name\"\n\n    # Multiple words\n    iex> Morpheus.camel_to_snake(\"userFirstName\")\n    \"user_first_name\"","ref":"Morpheus.html#camel_to_snake/1-string-conversion"},{"type":"function","title":"Acronym Handling - Morpheus.camel_to_snake/1","doc":"# Consecutive capitals\n    iex> Morpheus.camel_to_snake(\"API\")\n    \"api\"\n\n    # Mixed case acronyms\n    iex> Morpheus.camel_to_snake(\"APIResponse\")\n    \"api_response\"","ref":"Morpheus.html#camel_to_snake/1-acronym-handling"},{"type":"function","title":"Atom Conversion - Morpheus.camel_to_snake/1","doc":"iex> Morpheus.camel_to_snake(:userFirstName)\n    :user_first_name","ref":"Morpheus.html#camel_to_snake/1-atom-conversion"},{"type":"function","title":"Other Types - Morpheus.camel_to_snake/1","doc":"Returns the input unchanged if it's neither a string nor an atom:\n\n    iex> Morpheus.camel_to_snake(123)\n    123\n\n    iex> Morpheus.camel_to_snake([1, 2, 3])\n    [1, 2, 3]","ref":"Morpheus.html#camel_to_snake/1-other-types"},{"type":"function","title":"Morpheus.convert_map_keys/2","doc":"Recursively converts keys in maps and lists using the provided conversion function.","ref":"Morpheus.html#convert_map_keys/2"},{"type":"function","title":"Use Cases - Morpheus.convert_map_keys/2","doc":"* Converting API request/response payloads\n  * Transforming database results\n  * Normalizing data structures","ref":"Morpheus.html#convert_map_keys/2-use-cases"},{"type":"function","title":"Examples - Morpheus.convert_map_keys/2","doc":"","ref":"Morpheus.html#convert_map_keys/2-examples"},{"type":"function","title":"Nested Maps - Morpheus.convert_map_keys/2","doc":"iex> data = %{\n    ...>   \"userInfo\" => %{\n    ...>     \"firstName\" => \"John\",\n    ...>     \"lastName\" => \"Doe\"\n    ...>   }\n    ...> }\n    iex> Morpheus.convert_map_keys(data, &Morpheus.camel_to_snake/1)\n    %{\n      \"user_info\" => %{\n        \"first_name\" => \"John\",\n        \"last_name\" => \"Doe\"\n      }\n    }","ref":"Morpheus.html#convert_map_keys/2-nested-maps"},{"type":"function","title":"Lists of Maps - Morpheus.convert_map_keys/2","doc":"iex> users = [\n    ...>   %{user_id: 1, user_name: \"John\"},\n    ...>   %{user_id: 2, user_name: \"Jane\"}\n    ...> ]\n    iex> Morpheus.convert_map_keys(users, &Morpheus.snake_to_camel/1)\n    [\n      %{userId: 1, userName: \"John\"},\n      %{userId: 2, userName: \"Jane\"}\n    ]","ref":"Morpheus.html#convert_map_keys/2-lists-of-maps"},{"type":"function","title":"Mixed Key Types - Morpheus.convert_map_keys/2","doc":"iex> data = %{\"user_name\" => \"John\", last_name: \"Doe\"}\n    iex> Morpheus.convert_map_keys(data, &Morpheus.snake_to_camel/1)\n    %{\"userName\" => \"John\", lastName: \"Doe\"}","ref":"Morpheus.html#convert_map_keys/2-mixed-key-types"},{"type":"function","title":"Non-convertible Values - Morpheus.convert_map_keys/2","doc":"iex> Morpheus.convert_map_keys(\"not_a_map\", &Morpheus.snake_to_camel/1)\n    \"not_a_map\"","ref":"Morpheus.html#convert_map_keys/2-non-convertible-values"},{"type":"function","title":"Morpheus.snake_to_camel/1","doc":"Converts a snake_case string or atom to camelCase.","ref":"Morpheus.html#snake_to_camel/1"},{"type":"function","title":"String Conversion - Morpheus.snake_to_camel/1","doc":"# Basic conversion\n    iex> Morpheus.snake_to_camel(\"user_name\")\n    \"userName\"\n\n    # Multiple words\n    iex> Morpheus.snake_to_camel(\"user_first_name\")\n    \"userFirstName\"","ref":"Morpheus.html#snake_to_camel/1-string-conversion"},{"type":"function","title":"Special Cases - Morpheus.snake_to_camel/1","doc":"# Double underscores\n    iex> Morpheus.snake_to_camel(\"user__name\")\n    \"userName\"\n\n    # Acronyms\n    iex> Morpheus.snake_to_camel(\"api_key\")\n    \"apiKey\"\n\n    # All caps\n    iex> Morpheus.snake_to_camel(\"API\")\n    \"api\"","ref":"Morpheus.html#snake_to_camel/1-special-cases"},{"type":"function","title":"Atom Conversion - Morpheus.snake_to_camel/1","doc":"iex> Morpheus.snake_to_camel(:user_first_name)\n    :userFirstName","ref":"Morpheus.html#snake_to_camel/1-atom-conversion"},{"type":"function","title":"Other Types - Morpheus.snake_to_camel/1","doc":"Returns the input unchanged if it's neither a string nor an atom:\n\n    iex> Morpheus.snake_to_camel(123)\n    123","ref":"Morpheus.html#snake_to_camel/1-other-types"},{"type":"module","title":"Morpheus.Encoder","doc":"Transforms JSON responses in Phoenix applications from Elixir's snake_case to JavaScript's camelCase format.\n\nThis module allows you to work with idiomatic Elixir snake_case in your codebase\nwhile serving camelCase JSON to your API clients.","ref":"Morpheus.Encoder.html"},{"type":"module","title":"Setup - Morpheus.Encoder","doc":"In your config/config.exs, add after Jason config:\n\n    config :phoenix, :format_encoders, json: Morpheus.Encoder\n\nThat's it! Your JSON responses will now automatically convert keys to camelCase.","ref":"Morpheus.Encoder.html#module-setup"},{"type":"module","title":"Usage - Morpheus.Encoder","doc":"","ref":"Morpheus.Encoder.html#module-usage"},{"type":"module","title":"In Phoenix Controllers - Morpheus.Encoder","doc":"# No Changes required\n    def show(conn, _params) do\n      user = %{\n        user_id: 1,\n        first_name: \"John\",\n        last_name: \"Doe\"\n      }\n      json(conn, user)\n    end","ref":"Morpheus.Encoder.html#module-in-phoenix-controllers"},{"type":"module","title":"In JSON Views - Morpheus.Encoder","doc":"# No Changes required\n    defmodule MyAppWeb.UserJSON do\n      def show(%{user: user}) do\n        %{data: data(user)}\n      end\n\n      defp data(%User{} = user) do\n        %{\n          id: user.id,\n          first_name: user.first_name,\n          last_name: user.last_name\n        }\n      end\n    end","ref":"Morpheus.Encoder.html#module-in-json-views"},{"type":"module","title":"Direct Usage - Morpheus.Encoder","doc":"# For manual encoding when needed\n    Morpheus.Encoder.encode(%{user_name: \"John\"})","ref":"Morpheus.Encoder.html#module-direct-usage"},{"type":"module","title":"How it Works - Morpheus.Encoder","doc":"When Phoenix renders a JSON response, it uses this encoder which:\n1. Recursively traverses all maps and lists in the data structure\n2. Converts all keys from snake_case to camelCase\n3. Passes the transformed data to Jason for final JSON encoding","ref":"Morpheus.Encoder.html#module-how-it-works"},{"type":"module","title":"Configuration Options - Morpheus.Encoder","doc":"You can configure encoding options in your config:\n\n    config :morpheus, encode_options: [pretty: true]  # Passes these options to Jason.encode!/2","ref":"Morpheus.Encoder.html#module-configuration-options"},{"type":"function","title":"Morpheus.Encoder.encode/2","doc":"Encodes the given data structure to JSON with snake_case keys converted to camelCase.\n\nThis function is called automatically by Phoenix when rendering JSON responses.","ref":"Morpheus.Encoder.html#encode/2"},{"type":"function","title":"Parameters - Morpheus.Encoder.encode/2","doc":"* `data` - The Elixir data structure to be encoded\n  * `opts` - Optional keyword list of options to be passed to `Jason.encode!/2`","ref":"Morpheus.Encoder.html#encode/2-parameters"},{"type":"function","title":"Examples - Morpheus.Encoder.encode/2","doc":"iex> data = %{user_name: \"John Doe\", age: 30}\n    iex> Morpheus.Encoder.encode(data)\n    \"{\"age\":30,\"userName\":\"John Doe\"}\"\n\n    # With pretty printing\n    iex> data = %{user_name: \"John Doe\"}\n    iex> Morpheus.Encoder.encode(data, pretty: true)\n    \"\"\"\n    {\n      \"userName\": \"John Doe\"\n    }\n    \"\"\"\n\n    # Nested structures\n    iex> data = %{user_info: %{first_name: \"John\"}}\n    iex> Morpheus.Encoder.encode(data)\n    \"{\"userInfo\":{\"firstName\":\"John\"}}\"","ref":"Morpheus.Encoder.html#encode/2-examples"},{"type":"function","title":"Morpheus.Encoder.encode_to_iodata!/1","doc":"Encodes the given data structure to JSON with snake_case keys converted to camelCase,\nreturning an iodata.\n\nThis is useful when you want to avoid creating an intermediate binary string,\nespecially when dealing with large data structures.","ref":"Morpheus.Encoder.html#encode_to_iodata!/1"},{"type":"function","title":"Parameters - Morpheus.Encoder.encode_to_iodata!/1","doc":"* `data` - The Elixir data structure to be encoded","ref":"Morpheus.Encoder.html#encode_to_iodata!/1-parameters"},{"type":"function","title":"Examples - Morpheus.Encoder.encode_to_iodata!/1","doc":"# Basic usage\n    iex> data = %{user_name: \"John\"}\n    iex> iodata = Morpheus.Encoder.encode_to_iodata!(data)\n    iex> IO.iodata_to_binary(iodata)\n    \"{\"userName\":\"John\"}\"\n\n    # With nested structures\n    iex> data = %{user_info: %{first_name: \"John\"}}\n    iex> iodata = Morpheus.Encoder.encode_to_iodata!(data)\n    iex> IO.iodata_to_binary(iodata)\n    \"{\"userInfo\":{\"firstName\":\"John\"}}\"","ref":"Morpheus.Encoder.html#encode_to_iodata!/1-examples"},{"type":"module","title":"Morpheus.Plugs.SnakeCaseParams","doc":"A Phoenix plug that converts incoming request parameters from camelCase to snake_case.\r\n\r\nAutomatically converts parameter keys in incoming requests to match Elixir's snake_case\r\nconvention, letting you work with consistent naming in your Phoenix controllers.","ref":"Morpheus.Plugs.SnakeCaseParams.html"},{"type":"module","title":"Setup - Morpheus.Plugs.SnakeCaseParams","doc":"Add to your router pipeline:\r\n\r\n    pipeline :api do\r\n      plug :accepts, [\"json\"]\r\n      plug Morpheus.Plugs.SnakeCaseParams\r\n    end","ref":"Morpheus.Plugs.SnakeCaseParams.html#module-setup"},{"type":"module","title":"Example - Morpheus.Plugs.SnakeCaseParams","doc":"# Incoming request with params:\r\n    %{\r\n      \"userName\" => \"john_doe\",\r\n      \"userProfile\" => %{\r\n        \"firstName\" => \"John\",\r\n        \"lastName\" => \"Doe\"\r\n      }\r\n    }\r\n\r\n    # Parameters in your controller:\r\n    %{\r\n      \"user_name\" => \"john_doe\",\r\n      \"user_profile\" => %{\r\n        \"first_name\" => \"John\",\r\n        \"last_name\" => \"Doe\"\r\n      }\r\n    }","ref":"Morpheus.Plugs.SnakeCaseParams.html#module-example"},{"type":"module","title":"Key Features - Morpheus.Plugs.SnakeCaseParams","doc":"* Recursive conversion of nested maps and lists\r\n  * Works with both query parameters and request body\r\n  * Converts all parameter keys while preserving values\r\n  * Zero configuration required","ref":"Morpheus.Plugs.SnakeCaseParams.html#module-key-features"},{"type":"module","title":"Important Notes - Morpheus.Plugs.SnakeCaseParams","doc":"* All camelCase keys will be converted to snake_case\r\n  * The conversion modifies the `params` field of the connection\r\n  * If you need to preserve certain camelCase keys, handle them separately in your controller","ref":"Morpheus.Plugs.SnakeCaseParams.html#module-important-notes"},{"type":"function","title":"Morpheus.Plugs.SnakeCaseParams.call/2","doc":"Converts connection parameters from camelCase to snake_case.\r\n\r\nCalled at runtime for each request. Processes both URL query parameters\r\nand request body parameters.","ref":"Morpheus.Plugs.SnakeCaseParams.html#call/2"},{"type":"function","title":"Parameters - Morpheus.Plugs.SnakeCaseParams.call/2","doc":"* `conn` - The `Plug.Conn` struct for the current connection\r\n  * `_opts` - Options from `init/1` (currently unused)","ref":"Morpheus.Plugs.SnakeCaseParams.html#call/2-parameters"},{"type":"function","title":"Returns - Morpheus.Plugs.SnakeCaseParams.call/2","doc":"Returns the updated connection with converted parameters.","ref":"Morpheus.Plugs.SnakeCaseParams.html#call/2-returns"},{"type":"function","title":"Examples - Morpheus.Plugs.SnakeCaseParams.call/2","doc":"# Basic parameter conversion\r\n    # Given a request to \"/users?userName=john\"\r\n    conn = Morpheus.Plugs.SnakeCaseParams.call(conn, [])\r\n    conn.params\r\n    #=> %{\"user_name\" => \"john\"}\r\n\r\n    # Nested parameter conversion\r\n    # Given a POST with JSON: {\"userProfile\": {\"firstName\": \"John\"}}\r\n    conn = Morpheus.Plugs.SnakeCaseParams.call(conn, [])\r\n    conn.params\r\n    #=> %{\"user_profile\" => %{\"first_name\" => \"John\"}}","ref":"Morpheus.Plugs.SnakeCaseParams.html#call/2-examples"},{"type":"function","title":"Morpheus.Plugs.SnakeCaseParams.init/1","doc":"Initializes the plug with the given options.\r\n\r\nCalled at compile time. Currently accepts options for future extensibility.","ref":"Morpheus.Plugs.SnakeCaseParams.html#init/1"},{"type":"function","title":"Parameters - Morpheus.Plugs.SnakeCaseParams.init/1","doc":"* `opts` - A keyword list of options (currently unused)","ref":"Morpheus.Plugs.SnakeCaseParams.html#init/1-parameters"},{"type":"function","title":"Returns - Morpheus.Plugs.SnakeCaseParams.init/1","doc":"Returns the options unchanged.","ref":"Morpheus.Plugs.SnakeCaseParams.html#init/1-returns"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}